@@ -33,7 +33,9 @@ def data_bytes(n_bytes):
 
 
 def random_str(n):
-    return "".join(random.choice(string.ascii_uppercase + string.digits) for _ in range(n))
+    return "".join(
+        random.choice(string.ascii_uppercase + string.digits) for _ in range(n)
+    )
 
 
 def pq_enabled():
@@ -51,12 +53,17 @@ class AvailablePorts(object):
     """
 
     def __init__(self, low=8000, high=30000):
-        worker_count = int(os.getenv('PYTEST_XDIST_WORKER_COUNT'))
+        worker_count = 1
+        # If pytest is being run in parallel, worker processes will have
+        # the WORKER_COUNT variable set.
+        parallel_workers = os.getenv("PYTEST_XDIST_WORKER_COUNT")
+        if parallel_workers is not None:
+            worker_count = int(parallel_workers)
         chunk_size = int((high - low) / worker_count)
 
         # If xdist is being used, parse the workerid from the envvar. This can
         # be used to allocate unique ports to each worker.
-        worker = os.getenv('PYTEST_XDIST_WORKER')
+        worker = os.getenv("PYTEST_XDIST_WORKER")
         worker_id = 0
         if worker is not None:
             worker_id = re.findall(r"gw(\d+)", worker)
@@ -65,7 +72,7 @@ class AvailablePorts(object):
 
         # This is a naive way to allocate ports, but it allows us to cut
         # the run time in half without workers colliding.
-        worker_offset = (worker_id * chunk_size)
+        worker_offset = worker_id * chunk_size
         base_range = range(low + worker_offset, high)
         wrap_range = range(low, low + worker_offset)
         self.ports = iter(itertools.chain(base_range, wrap_range))
@@ -99,42 +106,44 @@ class Cert(object):
         self.name = name
         self.cert = location + prefix + "_cert.pem"
         self.key = location + prefix + "_key.pem"
-        self.algorithm = 'ANY'
+        self.algorithm = "ANY"
         self.curve = None
 
-        if 'ECDSA' in name:
-            self.algorithm = 'EC'
+        if "ECDSA" in name:
+            self.algorithm = "EC"
             self.curve = name[-3:]
-        elif 'RSA' in name:
-            self.algorithm = 'RSA'
-        if 'PSS' in name:
-            self.algorithm = 'RSAPSS'
+        elif "RSA" in name:
+            self.algorithm = "RSA"
+        if "PSS" in name:
+            self.algorithm = "RSAPSS"
 
     def compatible_with_cipher(self, cipher):
         if self.algorithm == cipher.algorithm:
             return True
         # TLS1.3 cipher suites do not specify auth method, so allow any auth method
-        if cipher.algorithm == 'ANY':
+        if cipher.algorithm == "ANY":
             return True
-        if self.algorithm == 'RSAPSS':
+        if self.algorithm == "RSAPSS":
             # RSA-PSS certs can only be used by ciphers with RSA auth
-            if cipher.algorithm != 'RSA':
+            if cipher.algorithm != "RSA":
                 return False
             # RSA-PSS certs do not support RSA key exchange, only RSA auth
             # "DHE" here is intended to capture both "DHE" and "ECDHE"
-            if 'DHE' in cipher.name:
+            if "DHE" in cipher.name:
                 return True
         return False
 
     def compatible_with_curve(self, curve):
-        if self.algorithm != 'EC':
+        if self.algorithm != "EC":
             return True
         return curve.name[-3:] == self.curve
 
     def compatible_with_sigalg(self, sigalg):
         if self.algorithm != sigalg.algorithm:
             return False
-        sig_alg_has_curve = sigalg.algorithm == 'EC' and sigalg.min_protocol == Protocols.TLS13
+        sig_alg_has_curve = (
+            sigalg.algorithm == "EC" and sigalg.min_protocol == Protocols.TLS13
+        )
         if sig_alg_has_curve and self.curve not in sigalg.name:
             return False
         return True
@@ -147,6 +156,7 @@ class Certificates(object):
     """
     When referencing certificates, use these values.
     """
+
     RSA_1024_SHA256 = Cert("RSA_1024_SHA256", "rsa_1024_sha256_client")
     RSA_1024_SHA384 = Cert("RSA_1024_SHA384", "rsa_1024_sha384_client")
     RSA_1024_SHA512 = Cert("RSA_1024_SHA512", "rsa_1024_sha512_client")
@@ -165,9 +175,9 @@ class Certificates(object):
     ECDSA_521 = Cert("ECDSA_521", "ecdsa_p521")
 
     RSA_2048_SHA256_WILDCARD = Cert(
-        "RSA_2048_SHA256_WILDCARD", "rsa_2048_sha256_wildcard")
-    RSA_PSS_2048_SHA256 = Cert(
-        "RSA_PSS_2048_SHA256", "localhost_rsa_pss_2048_sha256")
+        "RSA_2048_SHA256_WILDCARD", "rsa_2048_sha256_wildcard"
+    )
+    RSA_PSS_2048_SHA256 = Cert("RSA_PSS_2048_SHA256", "localhost_rsa_pss_2048_sha256")
 
     RSA_2048_PKCS1 = Cert("RSA_2048_PKCS1", "rsa_2048_pkcs1")
 
@@ -207,15 +217,27 @@ class Protocols(object):
     protocols. Since this is hardcoded in S2N, it is not
     expected to change.
     """
+
     TLS13 = Protocol("TLS1.3", 34)
     TLS12 = Protocol("TLS1.2", 33)
     TLS11 = Protocol("TLS1.1", 32)
     TLS10 = Protocol("TLS1.0", 31)
     SSLv3 = Protocol("SSLv3", 30)
+    SSLv2 = Protocol("SSLv2", 20)
 
 
 class Cipher(object):
-    def __init__(self, name, min_version, openssl1_1_1, fips, parameters=None, iana_standard_name=None, s2n=False, pq=False):
+    def __init__(
+        self,
+        name,
+        min_version,
+        openssl1_1_1,
+        fips,
+        parameters=None,
+        iana_standard_name=None,
+        s2n=False,
+        pq=False,
+    ):
         self.name = name
         self.min_version = min_version
         self.openssl1_1_1 = openssl1_1_1
@@ -226,13 +248,13 @@ class Cipher(object):
         self.pq = pq
 
         if self.min_version >= Protocols.TLS13:
-            self.algorithm = 'ANY'
+            self.algorithm = "ANY"
         elif iana_standard_name is None:
-            self.algorithm = 'ANY'
-        elif 'ECDSA' in iana_standard_name:
-            self.algorithm = 'EC'
-        elif 'RSA' in iana_standard_name:
-            self.algorithm = 'RSA'
+            self.algorithm = "ANY"
+        elif "ECDSA" in iana_standard_name:
+            self.algorithm = "EC"
+        elif "RSA" in iana_standard_name:
+            self.algorithm = "RSA"
         else:
             pytest.fail("Unknown signature algorithm on cipher")
 
@@ -250,106 +272,259 @@ class Ciphers(object):
     """
     When referencing ciphers, use these class values.
     """
-    DHE_RSA_DES_CBC3_SHA = Cipher("DHE-RSA-DES-CBC3-SHA", Protocols.SSLv3,
-                                  False, False, iana_standard_name="SSL_DHE_RSA_WITH_3DES_EDE_CBC_SHA")
-    DHE_RSA_AES128_SHA = Cipher("DHE-RSA-AES128-SHA", Protocols.SSLv3, True, False, TEST_CERT_DIRECTORY +
-                                'dhparams_2048.pem', iana_standard_name="TLS_DHE_RSA_WITH_AES_128_CBC_SHA")
-    DHE_RSA_AES256_SHA = Cipher("DHE-RSA-AES256-SHA", Protocols.SSLv3, True, False, TEST_CERT_DIRECTORY +
-                                'dhparams_2048.pem', iana_standard_name="TLS_DHE_RSA_WITH_AES_256_CBC_SHA")
-    DHE_RSA_AES128_SHA256 = Cipher("DHE-RSA-AES128-SHA256", Protocols.TLS12, True, True, TEST_CERT_DIRECTORY +
-                                   'dhparams_2048.pem', iana_standard_name="TLS_DHE_RSA_WITH_AES_128_CBC_SHA256")
-    DHE_RSA_AES256_SHA256 = Cipher("DHE-RSA-AES256-SHA256", Protocols.TLS12, True, True, TEST_CERT_DIRECTORY +
-                                   'dhparams_2048.pem', iana_standard_name="TLS_DHE_RSA_WITH_AES_256_CBC_SHA256")
-    DHE_RSA_AES128_GCM_SHA256 = Cipher("DHE-RSA-AES128-GCM-SHA256", Protocols.TLS12, True, True,
-                                       TEST_CERT_DIRECTORY + 'dhparams_2048.pem', iana_standard_name="TLS_DHE_RSA_WITH_AES_128_GCM_SHA256")
-    DHE_RSA_AES256_GCM_SHA384 = Cipher("DHE-RSA-AES256-GCM-SHA384", Protocols.TLS12, True, True,
-                                       TEST_CERT_DIRECTORY + 'dhparams_2048.pem', iana_standard_name="TLS_DHE_RSA_WITH_AES_256_GCM_SHA384")
-    DHE_RSA_CHACHA20_POLY1305 = Cipher("DHE-RSA-CHACHA20-POLY1305", Protocols.TLS12, True, False,
-                                       TEST_CERT_DIRECTORY + 'dhparams_2048.pem', iana_standard_name="TLS_DHE_RSA_WITH_AES_256_GCM_SHA384")
 
-    AES128_SHA = Cipher("AES128-SHA", Protocols.SSLv3, True,
-                        True, iana_standard_name="TLS_RSA_WITH_AES_128_CBC_SHA")
-    AES256_SHA = Cipher("AES256-SHA", Protocols.SSLv3, True,
-                        True, iana_standard_name="TLS_RSA_WITH_AES_256_CBC_SHA")
-    AES128_SHA256 = Cipher("AES128-SHA256", Protocols.TLS12, True,
-                           True, iana_standard_name="TLS_RSA_WITH_AES_128_CBC_SHA256")
-    AES256_SHA256 = Cipher("AES256-SHA256", Protocols.TLS12, True,
-                           True, iana_standard_name="TLS_RSA_WITH_AES_256_CBC_SHA256")
-    AES128_GCM_SHA256 = Cipher("TLS_AES_128_GCM_SHA256", Protocols.TLS13,
-                               True, True, iana_standard_name="TLS_AES_128_GCM_SHA256")
-    AES256_GCM_SHA384 = Cipher("TLS_AES_256_GCM_SHA384", Protocols.TLS13,
-                               True, True, iana_standard_name="TLS_AES_256_GCM_SHA384")
+    DHE_RSA_DES_CBC3_SHA = Cipher(
+        "DHE-RSA-DES-CBC3-SHA",
+        Protocols.SSLv3,
+        False,
+        False,
+        iana_standard_name="SSL_DHE_RSA_WITH_3DES_EDE_CBC_SHA",
+    )
+    DHE_RSA_AES128_SHA = Cipher(
+        "DHE-RSA-AES128-SHA",
+        Protocols.SSLv3,
+        True,
+        False,
+        TEST_CERT_DIRECTORY + "dhparams_2048.pem",
+        iana_standard_name="TLS_DHE_RSA_WITH_AES_128_CBC_SHA",
+    )
+    DHE_RSA_AES256_SHA = Cipher(
+        "DHE-RSA-AES256-SHA",
+        Protocols.SSLv3,
+        True,
+        False,
+        TEST_CERT_DIRECTORY + "dhparams_2048.pem",
+        iana_standard_name="TLS_DHE_RSA_WITH_AES_256_CBC_SHA",
+    )
+    DHE_RSA_AES128_SHA256 = Cipher(
+        "DHE-RSA-AES128-SHA256",
+        Protocols.TLS12,
+        True,
+        True,
+        TEST_CERT_DIRECTORY + "dhparams_2048.pem",
+        iana_standard_name="TLS_DHE_RSA_WITH_AES_128_CBC_SHA256",
+    )
+    DHE_RSA_AES256_SHA256 = Cipher(
+        "DHE-RSA-AES256-SHA256",
+        Protocols.TLS12,
+        True,
+        True,
+        TEST_CERT_DIRECTORY + "dhparams_2048.pem",
+        iana_standard_name="TLS_DHE_RSA_WITH_AES_256_CBC_SHA256",
+    )
+    DHE_RSA_AES128_GCM_SHA256 = Cipher(
+        "DHE-RSA-AES128-GCM-SHA256",
+        Protocols.TLS12,
+        True,
+        True,
+        TEST_CERT_DIRECTORY + "dhparams_2048.pem",
+        iana_standard_name="TLS_DHE_RSA_WITH_AES_128_GCM_SHA256",
+    )
+    DHE_RSA_AES256_GCM_SHA384 = Cipher(
+        "DHE-RSA-AES256-GCM-SHA384",
+        Protocols.TLS12,
+        True,
+        True,
+        TEST_CERT_DIRECTORY + "dhparams_2048.pem",
+        iana_standard_name="TLS_DHE_RSA_WITH_AES_256_GCM_SHA384",
+    )
+    DHE_RSA_CHACHA20_POLY1305 = Cipher(
+        "DHE-RSA-CHACHA20-POLY1305",
+        Protocols.TLS12,
+        True,
+        False,
+        TEST_CERT_DIRECTORY + "dhparams_2048.pem",
+        iana_standard_name="TLS_DHE_RSA_WITH_AES_256_GCM_SHA384",
+    )
 
-    ECDHE_ECDSA_AES128_SHA = Cipher("ECDHE-ECDSA-AES128-SHA", Protocols.SSLv3,
-                                    True, False, iana_standard_name="TLS_ECDHE_ECDSA_WITH_AES_128_CBC_SHA")
-    ECDHE_ECDSA_AES256_SHA = Cipher("ECDHE-ECDSA-AES256-SHA", Protocols.SSLv3,
-                                    True, False, iana_standard_name="TLS_ECDHE_ECDSA_WITH_AES_256_CBC_SHA")
-    ECDHE_ECDSA_AES128_SHA256 = Cipher("ECDHE-ECDSA-AES128-SHA256", Protocols.TLS12,
-                                       True, True, iana_standard_name="TLS_ECDHE_ECDSA_WITH_AES_128_CBC_SHA256")
-    ECDHE_ECDSA_AES256_SHA384 = Cipher("ECDHE-ECDSA-AES256-SHA384", Protocols.TLS12,
-                                       True, True, iana_standard_name="TLS_ECDHE_ECDSA_WITH_AES_256_CBC_SHA384")
-    ECDHE_ECDSA_AES128_GCM_SHA256 = Cipher("ECDHE-ECDSA-AES128-GCM-SHA256", Protocols.TLS12,
-                                           True, True, iana_standard_name="TLS_ECDHE_ECDSA_WITH_AES_128_GCM_SHA256")
-    ECDHE_ECDSA_AES256_GCM_SHA384 = Cipher("ECDHE-ECDSA-AES256-GCM-SHA384", Protocols.TLS12,
-                                           True, True, iana_standard_name="TLS_ECDHE_ECDSA_WITH_AES_256_GCM_SHA384")
-    ECDHE_ECDSA_CHACHA20_POLY1305 = Cipher("ECDHE-ECDSA-CHACHA20-POLY1305", Protocols.TLS12,
-                                           True, False, iana_standard_name="TLS_ECDHE_ECDSA_WITH_CHACHA20_POLY1305_SHA256")
+    AES128_SHA = Cipher(
+        "AES128-SHA",
+        Protocols.SSLv3,
+        True,
+        True,
+        iana_standard_name="TLS_RSA_WITH_AES_128_CBC_SHA",
+    )
+    AES256_SHA = Cipher(
+        "AES256-SHA",
+        Protocols.SSLv3,
+        True,
+        True,
+        iana_standard_name="TLS_RSA_WITH_AES_256_CBC_SHA",
+    )
+    AES128_SHA256 = Cipher(
+        "AES128-SHA256",
+        Protocols.TLS12,
+        True,
+        True,
+        iana_standard_name="TLS_RSA_WITH_AES_128_CBC_SHA256",
+    )
+    AES256_SHA256 = Cipher(
+        "AES256-SHA256",
+        Protocols.TLS12,
+        True,
+        True,
+        iana_standard_name="TLS_RSA_WITH_AES_256_CBC_SHA256",
+    )
+    AES128_GCM_SHA256 = Cipher(
+        "TLS_AES_128_GCM_SHA256",
+        Protocols.TLS13,
+        True,
+        True,
+        iana_standard_name="TLS_AES_128_GCM_SHA256",
+    )
+    AES256_GCM_SHA384 = Cipher(
+        "TLS_AES_256_GCM_SHA384",
+        Protocols.TLS13,
+        True,
+        True,
+        iana_standard_name="TLS_AES_256_GCM_SHA384",
+    )
 
-    ECDHE_RSA_DES_CBC3_SHA = Cipher("ECDHE-RSA-DES-CBC3-SHA", Protocols.SSLv3,
-                                    False, False, iana_standard_name="TLS_ECDHE_RSA_WITH_3DES_EDE_CBC_SHA")
-    ECDHE_RSA_AES128_SHA = Cipher("ECDHE-RSA-AES128-SHA", Protocols.SSLv3,
-                                  True, False, iana_standard_name="TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA")
-    ECDHE_RSA_AES256_SHA = Cipher("ECDHE-RSA-AES256-SHA", Protocols.SSLv3,
-                                  True, False, iana_standard_name="TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA")
-    ECDHE_RSA_RC4_SHA = Cipher("ECDHE-RSA-RC4-SHA", Protocols.SSLv3,
-                               False, False, iana_standard_name="TLS_ECDHE_RSA_WITH_RC4_128_SHA")
-    ECDHE_RSA_AES128_SHA256 = Cipher("ECDHE-RSA-AES128-SHA256", Protocols.TLS12,
-                                     True, True, iana_standard_name="TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA256")
-    ECDHE_RSA_AES256_SHA384 = Cipher("ECDHE-RSA-AES256-SHA384", Protocols.TLS12,
-                                     True, True, iana_standard_name="TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA384")
-    ECDHE_RSA_AES128_GCM_SHA256 = Cipher("ECDHE-RSA-AES128-GCM-SHA256", Protocols.TLS12,
-                                         True, True, iana_standard_name="TLS_ECDHE_RSA_WITH_AES_128_GCM_SHA256")
-    ECDHE_RSA_AES256_GCM_SHA384 = Cipher("ECDHE-RSA-AES256-GCM-SHA384", Protocols.TLS12,
-                                         True, True, iana_standard_name="TLS_ECDHE_RSA_WITH_AES_256_GCM_SHA384")
-    ECDHE_RSA_CHACHA20_POLY1305 = Cipher("ECDHE-RSA-CHACHA20-POLY1305", Protocols.TLS12,
-                                         True, False, iana_standard_name="TLS_ECDHE_RSA_WITH_CHACHA20_POLY1305_SHA256")
-    CHACHA20_POLY1305_SHA256 = Cipher("TLS_CHACHA20_POLY1305_SHA256", Protocols.TLS13,
-                                      True, False, iana_standard_name="TLS_CHACHA20_POLY1305_SHA256")
+    ECDHE_ECDSA_AES128_SHA = Cipher(
+        "ECDHE-ECDSA-AES128-SHA",
+        Protocols.SSLv3,
+        True,
+        False,
+        iana_standard_name="TLS_ECDHE_ECDSA_WITH_AES_128_CBC_SHA",
+    )
+    ECDHE_ECDSA_AES256_SHA = Cipher(
+        "ECDHE-ECDSA-AES256-SHA",
+        Protocols.SSLv3,
+        True,
+        False,
+        iana_standard_name="TLS_ECDHE_ECDSA_WITH_AES_256_CBC_SHA",
+    )
+    ECDHE_ECDSA_AES128_SHA256 = Cipher(
+        "ECDHE-ECDSA-AES128-SHA256",
+        Protocols.TLS12,
+        True,
+        True,
+        iana_standard_name="TLS_ECDHE_ECDSA_WITH_AES_128_CBC_SHA256",
+    )
+    ECDHE_ECDSA_AES256_SHA384 = Cipher(
+        "ECDHE-ECDSA-AES256-SHA384",
+        Protocols.TLS12,
+        True,
+        True,
+        iana_standard_name="TLS_ECDHE_ECDSA_WITH_AES_256_CBC_SHA384",
+    )
+    ECDHE_ECDSA_AES128_GCM_SHA256 = Cipher(
+        "ECDHE-ECDSA-AES128-GCM-SHA256",
+        Protocols.TLS12,
+        True,
+        True,
+        iana_standard_name="TLS_ECDHE_ECDSA_WITH_AES_128_GCM_SHA256",
+    )
+    ECDHE_ECDSA_AES256_GCM_SHA384 = Cipher(
+        "ECDHE-ECDSA-AES256-GCM-SHA384",
+        Protocols.TLS12,
+        True,
+        True,
+        iana_standard_name="TLS_ECDHE_ECDSA_WITH_AES_256_GCM_SHA384",
+    )
+    ECDHE_ECDSA_CHACHA20_POLY1305 = Cipher(
+        "ECDHE-ECDSA-CHACHA20-POLY1305",
+        Protocols.TLS12,
+        True,
+        False,
+        iana_standard_name="TLS_ECDHE_ECDSA_WITH_CHACHA20_POLY1305_SHA256",
+    )
+
+    ECDHE_RSA_DES_CBC3_SHA = Cipher(
+        "ECDHE-RSA-DES-CBC3-SHA",
+        Protocols.SSLv3,
+        False,
+        False,
+        iana_standard_name="TLS_ECDHE_RSA_WITH_3DES_EDE_CBC_SHA",
+    )
+    ECDHE_RSA_AES128_SHA = Cipher(
+        "ECDHE-RSA-AES128-SHA",
+        Protocols.SSLv3,
+        True,
+        False,
+        iana_standard_name="TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA",
+    )
+    ECDHE_RSA_AES256_SHA = Cipher(
+        "ECDHE-RSA-AES256-SHA",
+        Protocols.SSLv3,
+        True,
+        False,
+        iana_standard_name="TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA",
+    )
+    ECDHE_RSA_RC4_SHA = Cipher(
+        "ECDHE-RSA-RC4-SHA",
+        Protocols.SSLv3,
+        False,
+        False,
+        iana_standard_name="TLS_ECDHE_RSA_WITH_RC4_128_SHA",
+    )
+    ECDHE_RSA_AES128_SHA256 = Cipher(
+        "ECDHE-RSA-AES128-SHA256",
+        Protocols.TLS12,
+        True,
+        True,
+        iana_standard_name="TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA256",
+    )
+    ECDHE_RSA_AES256_SHA384 = Cipher(
+        "ECDHE-RSA-AES256-SHA384",
+        Protocols.TLS12,
+        True,
+        True,
+        iana_standard_name="TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA384",
+    )
+    ECDHE_RSA_AES128_GCM_SHA256 = Cipher(
+        "ECDHE-RSA-AES128-GCM-SHA256",
+        Protocols.TLS12,
+        True,
+        True,
+        iana_standard_name="TLS_ECDHE_RSA_WITH_AES_128_GCM_SHA256",
+    )
+    ECDHE_RSA_AES256_GCM_SHA384 = Cipher(
+        "ECDHE-RSA-AES256-GCM-SHA384",
+        Protocols.TLS12,
+        True,
+        True,
+        iana_standard_name="TLS_ECDHE_RSA_WITH_AES_256_GCM_SHA384",
+    )
+    ECDHE_RSA_CHACHA20_POLY1305 = Cipher(
+        "ECDHE-RSA-CHACHA20-POLY1305",
+        Protocols.TLS12,
+        True,
+        False,
+        iana_standard_name="TLS_ECDHE_RSA_WITH_CHACHA20_POLY1305_SHA256",
+    )
+    CHACHA20_POLY1305_SHA256 = Cipher(
+        "TLS_CHACHA20_POLY1305_SHA256",
+        Protocols.TLS13,
+        True,
+        False,
+        iana_standard_name="TLS_CHACHA20_POLY1305_SHA256",
+    )
 
     KMS_TLS_1_0_2018_10 = Cipher(
-        "KMS-TLS-1-0-2018-10", Protocols.TLS10, False, False, s2n=True)
-    KMS_PQ_TLS_1_0_2019_06 = Cipher(
-        "KMS-PQ-TLS-1-0-2019-06", Protocols.TLS10, False, False, s2n=True, pq=True)
-    KMS_PQ_TLS_1_0_2020_02 = Cipher(
-        "KMS-PQ-TLS-1-0-2020-02", Protocols.TLS10, False, False, s2n=True, pq=True)
-    KMS_PQ_TLS_1_0_2020_07 = Cipher(
-        "KMS-PQ-TLS-1-0-2020-07", Protocols.TLS10, False, False, s2n=True, pq=True)
-    PQ_SIKE_TEST_TLS_1_0_2019_11 = Cipher(
-        "PQ-SIKE-TEST-TLS-1-0-2019-11", Protocols.TLS10, False, False, s2n=True, pq=True)
-    PQ_SIKE_TEST_TLS_1_0_2020_02 = Cipher(
-        "PQ-SIKE-TEST-TLS-1-0-2020-02", Protocols.TLS10, False, False, s2n=True, pq=True)
-    PQ_TLS_1_0_2020_12 = Cipher(
-        "PQ-TLS-1-0-2020-12", Protocols.TLS10, False, False, s2n=True, pq=True)
+        "KMS-TLS-1-0-2018-10", Protocols.TLS10, False, False, s2n=True
+    )
     PQ_TLS_1_0_2023_01 = Cipher(
-        "PQ-TLS-1-0-2023-01-24", Protocols.TLS10, False, False, s2n=True, pq=True)
+        "PQ-TLS-1-0-2023-01-24", Protocols.TLS10, False, False, s2n=True, pq=True
+    )
     PQ_TLS_1_3_2023_06_01 = Cipher(
-        "PQ-TLS-1-3-2023-06-01", Protocols.TLS12, False, False, s2n=True, pq=True)
+        "PQ-TLS-1-3-2023-06-01", Protocols.TLS12, False, False, s2n=True, pq=True
+    )
 
     SECURITY_POLICY_20210816 = Cipher(
-        "20210816", Protocols.TLS12, False, False, s2n=True, pq=False)
+        "20210816", Protocols.TLS12, False, False, s2n=True, pq=False
+    )
 
     @staticmethod
     def from_iana(iana_name):
         ciphers = [
-            cipher for attr in vars(Ciphers)
+            cipher
+            for attr in vars(Ciphers)
             if not callable(cipher := getattr(Ciphers, attr))
             and not attr.startswith("_")
             and cipher.iana_standard_name
         ]
-        return {
-            cipher.iana_standard_name: cipher
-            for cipher in ciphers
-        }.get(iana_name)
+        return {cipher.iana_standard_name: cipher for cipher in ciphers}.get(iana_name)
 
 
 class Curve(object):
@@ -366,6 +541,7 @@ class Curves(object):
     When referencing curves, use these class values.
     Don't hardcode curve names.
     """
+
     X25519 = Curve("X25519", Protocols.TLS13)
     P256 = Curve("P-256")
     # Our only SSLv3 provider doesn't support extensions
@@ -379,15 +555,13 @@ class Curves(object):
     @staticmethod
     def from_name(name):
         curves = [
-            curve for attr in vars(Curves)
+            curve
+            for attr in vars(Curves)
             if not callable(curve := getattr(Curves, attr))
             and not attr.startswith("_")
             and curve.name
         ]
-        return {
-            curve.name: curve
-            for curve in curves
-        }.get(name)
+        return {curve.name: curve for curve in curves}.get(name)
 
 
 class KemGroup(object):
@@ -412,19 +586,26 @@ class KemGroups(object):
 
 
 class Signature(object):
-    def __init__(self, name, min_protocol=Protocols.SSLv3, max_protocol=Protocols.TLS13, sig_type=None, sig_digest=None):
+    def __init__(
+        self,
+        name,
+        min_protocol=Protocols.SSLv3,
+        max_protocol=Protocols.TLS13,
+        sig_type=None,
+        sig_digest=None,
+    ):
         self.min_protocol = min_protocol
         self.max_protocol = max_protocol
 
-        if 'RSA' in name.upper():
-            self.algorithm = 'RSA'
-        if 'PSS_PSS' in name.upper():
-            self.algorithm = 'RSAPSS'
-        if 'EC' in name.upper() or 'ED' in name.upper():
-            self.algorithm = 'EC'
+        if "RSA" in name.upper():
+            self.algorithm = "RSA"
+        if "PSS_PSS" in name.upper():
+            self.algorithm = "RSAPSS"
+        if "EC" in name.upper() or "ED" in name.upper():
+            self.algorithm = "EC"
 
-        if not (sig_type or sig_digest) and '+' in name:
-            sig_type, sig_digest = name.split('+')
+        if not (sig_type or sig_digest) and "+" in name:
+            sig_type, sig_digest = name.split("+")
 
         self.name = name
 
@@ -436,44 +617,47 @@ class Signature(object):
 
 
 class Signatures(object):
-    RSA_SHA1 = Signature('RSA+SHA1',   max_protocol=Protocols.TLS12)
-    RSA_SHA224 = Signature('RSA+SHA224', max_protocol=Protocols.TLS12)
-    RSA_SHA256 = Signature('RSA+SHA256', max_protocol=Protocols.TLS12)
-    RSA_SHA384 = Signature('RSA+SHA384', max_protocol=Protocols.TLS12)
-    RSA_SHA512 = Signature('RSA+SHA512', max_protocol=Protocols.TLS12)
-    RSA_MD5_SHA1 = Signature('RSA+MD5_SHA1', max_protocol=Protocols.TLS11)
-    ECDSA_SHA224 = Signature('ECDSA+SHA224', max_protocol=Protocols.TLS12)
-    ECDSA_SHA256 = Signature('ECDSA+SHA256', max_protocol=Protocols.TLS12)
-    ECDSA_SHA384 = Signature('ECDSA+SHA384', max_protocol=Protocols.TLS12)
-    ECDSA_SHA512 = Signature('ECDSA+SHA512', max_protocol=Protocols.TLS12)
-    ECDSA_SHA1 = Signature('ECDSA+SHA1', max_protocol=Protocols.TLS12)
+    RSA_SHA1 = Signature("RSA+SHA1", max_protocol=Protocols.TLS12)
+    RSA_SHA224 = Signature("RSA+SHA224", max_protocol=Protocols.TLS12)
+    RSA_SHA256 = Signature("RSA+SHA256", max_protocol=Protocols.TLS12)
+    RSA_SHA384 = Signature("RSA+SHA384", max_protocol=Protocols.TLS12)
+    RSA_SHA512 = Signature("RSA+SHA512", max_protocol=Protocols.TLS12)
+    RSA_MD5_SHA1 = Signature("RSA+MD5_SHA1", max_protocol=Protocols.TLS11)
+    ECDSA_SHA224 = Signature("ECDSA+SHA224", max_protocol=Protocols.TLS12)
+    ECDSA_SHA256 = Signature("ECDSA+SHA256", max_protocol=Protocols.TLS12)
+    ECDSA_SHA384 = Signature("ECDSA+SHA384", max_protocol=Protocols.TLS12)
+    ECDSA_SHA512 = Signature("ECDSA+SHA512", max_protocol=Protocols.TLS12)
+    ECDSA_SHA1 = Signature("ECDSA+SHA1", max_protocol=Protocols.TLS12)
 
     RSA_PSS_RSAE_SHA256 = Signature(
-        'RSA-PSS+SHA256',
-        sig_type='RSA-PSS-RSAE',
-        sig_digest='SHA256')
+        "RSA-PSS+SHA256", sig_type="RSA-PSS-RSAE", sig_digest="SHA256"
+    )
 
     RSA_PSS_PSS_SHA256 = Signature(
-        'rsa_pss_pss_sha256',
+        "rsa_pss_pss_sha256",
         min_protocol=Protocols.TLS12,
-        sig_type='RSA-PSS-PSS',
-        sig_digest='SHA256')
+        sig_type="RSA-PSS-PSS",
+        sig_digest="SHA256",
+    )
 
     ECDSA_SECP256r1_SHA256 = Signature(
-        'ecdsa_secp256r1_sha256',
+        "ecdsa_secp256r1_sha256",
         min_protocol=Protocols.TLS13,
-        sig_type='ECDSA',
-        sig_digest='SHA256')
+        sig_type="ECDSA",
+        sig_digest="SHA256",
+    )
     ECDSA_SECP384r1_SHA384 = Signature(
-        'ecdsa_secp384r1_sha384',
+        "ecdsa_secp384r1_sha384",
         min_protocol=Protocols.TLS13,
-        sig_type='ECDSA',
-        sig_digest='SHA384')
+        sig_type="ECDSA",
+        sig_digest="SHA384",
+    )
     ECDSA_SECP521r1_SHA512 = Signature(
-        'ecdsa_secp521r1_sha512',
+        "ecdsa_secp521r1_sha512",
         min_protocol=Protocols.TLS13,
-        sig_type='ECDSA',
-        sig_digest='SHA512')
+        sig_type="ECDSA",
+        sig_digest="SHA512",
+    )
 
 
 class Results(object):
@@ -494,7 +678,15 @@ class Results(object):
     # Any exception thrown while running the process
     exception = None
 
-    def __init__(self, stdout, stderr, exit_code, exception, expect_stderr=False, expect_nonzero_exit=False):
+    def __init__(
+        self,
+        stdout,
+        stderr,
+        exit_code,
+        exception,
+        expect_stderr=False,
+        expect_nonzero_exit=False,
+    ):
         self.stdout = stdout
         self.stderr = stderr
         self.exit_code = exit_code
@@ -503,7 +695,9 @@ class Results(object):
         self.expect_nonzero_exit = expect_nonzero_exit
 
     def __str__(self):
-        return "Stdout: {}\nStderr: {}\nExit code: {}\nException: {}".format(self.stdout, self.stderr, self.exit_code, self.exception)
+        return "Stdout: {}\nStderr: {}\nExit code: {}\nException: {}".format(
+            self.stdout, self.stderr, self.exit_code, self.exception
+        )
 
     def assert_success(self):
         assert self.exception is None, self.exception
@@ -518,34 +712,33 @@ class Results(object):
 
 class ProviderOptions(object):
     def __init__(
-            self,
-            mode=None,
-            host=None,
-            port=None,
-            cipher=None,
-            curve=None,
-            key=None,
-            cert=None,
-            use_session_ticket=False,
-            insecure=False,
-            data_to_send=None,
-            use_client_auth=False,
-            extra_flags=None,
-            trust_store=None,
-            reconnects_before_exit=None,
-            reconnect=None,
-            verify_hostname=None,
-            server_name=None,
-            protocol=None,
-            use_mainline_version=None,
-            env_overrides=dict(),
-            enable_client_ocsp=False,
-            ocsp_response=None,
-            signature_algorithm=None,
-            record_size=None,
-            verbose=True
+        self,
+        mode=None,
+        host=None,
+        port=None,
+        cipher=None,
+        curve=None,
+        key=None,
+        cert=None,
+        use_session_ticket=False,
+        insecure=False,
+        data_to_send=None,
+        use_client_auth=False,
+        extra_flags=None,
+        trust_store=None,
+        reconnects_before_exit=None,
+        reconnect=None,
+        verify_hostname=None,
+        server_name=None,
+        protocol=None,
+        use_mainline_version=None,
+        env_overrides=dict(),
+        enable_client_ocsp=False,
+        ocsp_response=None,
+        signature_algorithm=None,
+        record_size=None,
+        verbose=True,
     ):
-
         # Client or server
         self.mode = mode
 
@@ -574,7 +767,7 @@ class ProviderOptions(object):
         # Boolean whether to use a resumption ticket
         self.use_session_ticket = use_session_ticket
 
-        # Boolean whether to allow insecure certificates
+        # Boolean whether to disable x509 verification
         self.insecure = insecure
 
         # Which protocol to use with this provider
