@@ -5,7 +5,7 @@ import subprocess
 import pytest
 import threading
 
-from common import ProviderOptions, Ciphers, Curves, Protocols, Signatures
+from common import ProviderOptions, Ciphers, Curves, Protocols, Signatures, Cert
 from global_flags import get_flag, S2N_PROVIDER_VERSION, S2N_FIPS_MODE
 from stat import S_IMODE
 
@@ -72,7 +72,7 @@ class Provider(object):
         return None
 
     @classmethod
-    def supports_protocol(cls, protocol, with_cert=None):
+    def supports_protocol(cls, protocol):
         raise NotImplementedError
 
     @classmethod
@@ -94,6 +94,10 @@ class Provider(object):
             self._provider_ready = True
             self._provider_ready_condition.notify()
 
+    @classmethod
+    def supports_certificate(cls, cert: Cert):
+        return True
+
 
 class Tcpdump(Provider):
     """
@@ -108,26 +112,27 @@ class Tcpdump(Provider):
         Provider.__init__(self, options)
 
     def setup_client(self):
-        self.ready_to_test_marker = 'listening on lo'
+        self.ready_to_test_marker = "listening on lo"
         tcpdump_filter = "dst port {}".format(self.options.port)
 
-        cmd_line = ["tcpdump",
-                    # Line buffer the output
-                    "-l",
-
-                    # Only read 10 packets before exiting. This is enough to find a large
-                    # packet, and still exit before the timeout.
-                    "-c", "10",
-
-                    # Watch the loopback device
-                    "-i", "lo",
-
-                    # Don't resolve IP addresses
-                    "-nn",
-
-                    # Set the buffer size to 1k
-                    "-B", "1024",
-                    tcpdump_filter]
+        cmd_line = [
+            "tcpdump",
+            # Line buffer the output
+            "-l",
+            # Only read 10 packets before exiting. This is enough to find a large
+            # packet, and still exit before the timeout.
+            "-c",
+            "10",
+            # Watch the loopback device
+            "-i",
+            "lo",
+            # Don't resolve IP addresses
+            "-nn",
+            # Set the buffer size to 1k
+            "-B",
+            "1024",
+            tcpdump_filter,
+        ]
 
         return cmd_line
 
@@ -144,35 +149,39 @@ class S2N(Provider):
 
     @classmethod
     def get_send_marker(cls):
-        return 's2n is ready'
+        return "s2n is ready"
 
     @classmethod
-    def supports_protocol(cls, protocol, with_cert=None):
+    def _pss_supported(cls):
         # RSA-PSS is unsupported for openssl-1.0
         # libressl and boringssl are disabled because of configuration issues
         # see https://github.com/aws/s2n-tls/issues/3250
-        PSS_UNSUPPORTED_LIBCRYPTOS = {
-            "libressl",
-            "boringssl",
-            "openssl-1.0"
-        }
-        pss_is_unsupported = any([
+        PSS_UNSUPPORTED_LIBCRYPTOS = {"libressl", "boringssl", "openssl-1.0"}
+        for libcrypto in PSS_UNSUPPORTED_LIBCRYPTOS:
             # e.g. "openssl-1.0" in "openssl-1.0.2-fips"
-            libcrypto in get_flag(S2N_PROVIDER_VERSION)
-            for libcrypto in PSS_UNSUPPORTED_LIBCRYPTOS
-        ])
-        if pss_is_unsupported:
-            if protocol == Protocols.TLS13:
-                return False
-            if with_cert and with_cert.algorithm == 'RSAPSS':
+            if libcrypto in get_flag(S2N_PROVIDER_VERSION):
                 return False
+        return True
+
+    @classmethod
+    def supports_certificate(cls, cert: Cert):
+        if not cls._pss_supported() and cert.algorithm == "RSAPSS":
+            return False
+        return True
+
+    @classmethod
+    def supports_protocol(cls, protocol):
+        if not cls._pss_supported() and protocol == Protocols.TLS13:
+            return False
 
         # SSLv3 cannot be negotiated in FIPS mode with libcryptos other than AWS-LC.
-        if all([
-            protocol == Protocols.SSLv3,
-            get_flag(S2N_FIPS_MODE),
-            "awslc" not in get_flag(S2N_PROVIDER_VERSION)
-        ]):
+        if all(
+            [
+                protocol == Protocols.SSLv3,
+                get_flag(S2N_FIPS_MODE),
+                "awslc" not in get_flag(S2N_PROVIDER_VERSION),
+            ]
+        ):
             return False
 
         return True
@@ -186,7 +195,10 @@ class S2N(Provider):
             "RC4": ["openssl-3"],
         }
 
-        for unsupported_cipher, unsupported_libcryptos in unsupported_configurations.items():
+        for (
+            unsupported_cipher,
+            unsupported_libcryptos,
+        ) in unsupported_configurations.items():
             # the queried cipher has some libcrypto's that don't support it
             # e.g. "RC4" in "TLS_ECDHE_RSA_WITH_RC4_128_SHA"
             if unsupported_cipher in cipher.name:
@@ -200,14 +212,15 @@ class S2N(Provider):
     @classmethod
     def supports_signature(cls, signature):
         # Disable RSA_PSS_RSAE_SHA256 in unsupported libcryptos
-        if any([
-            libcrypto in get_flag(S2N_PROVIDER_VERSION)
-            for libcrypto in [
-                "openssl-1.0.2",
-                "libressl",
-                "boringssl"
-            ]
-        ]) and signature == Signatures.RSA_PSS_RSAE_SHA256:
+        if (
+            any(
+                [
+                    libcrypto in get_flag(S2N_PROVIDER_VERSION)
+                    for libcrypto in ["openssl-1.0.2", "libressl", "boringssl"]
+                ]
+            )
+            and signature == Signatures.RSA_PSS_RSAE_SHA256
+        ):
             return False
 
         return True
@@ -218,44 +231,44 @@ class S2N(Provider):
         """
         cmd_line = []
         if self.options.use_mainline_version is True:
-            cmd_line.append('s2nc_head')
+            cmd_line.append("s2nc_head")
         else:
-            cmd_line.append('s2nc')
-        cmd_line.append('--non-blocking')
+            cmd_line.append("s2nc")
+        cmd_line.append("--non-blocking")
 
         # Tests requiring reconnects can't wait on echo data,
         # but all other tests can.
         if self.options.reconnect is not True:
-            cmd_line.append('-e')
+            cmd_line.append("-e")
 
         if self.options.use_session_ticket is False:
-            cmd_line.append('-T')
+            cmd_line.append("-T")
 
         if self.options.insecure is True:
-            cmd_line.append('--insecure')
+            cmd_line.append("--insecure")
         elif self.options.trust_store:
-            cmd_line.extend(['-f', self.options.trust_store])
+            cmd_line.extend(["-f", self.options.trust_store])
         elif self.options.cert:
-            cmd_line.extend(['-f', self.options.cert])
+            cmd_line.extend(["-f", self.options.cert])
 
         if self.options.reconnect is True:
-            cmd_line.append('-r')
+            cmd_line.append("-r")
 
         # If the test provided a cipher (security policy) that is compatible with
         # s2n, we'll use it. Otherwise, default to the appropriate `test_all` policy.
-        cipher_prefs = 'test_all_tls12'
+        cipher_prefs = "test_all_tls12"
         if self.options.protocol is Protocols.TLS13:
-            cipher_prefs = 'test_all'
+            cipher_prefs = "test_all"
         if self.options.cipher and self.options.cipher.s2n:
             cipher_prefs = self.options.cipher.name
 
-        cmd_line.extend(['-c', cipher_prefs])
+        cmd_line.extend(["-c", cipher_prefs])
 
         if self.options.use_client_auth:
             if self.options.key:
-                cmd_line.extend(['--key', self.options.key])
+                cmd_line.extend(["--key", self.options.key])
             if self.options.cert:
-                cmd_line.extend(['--cert', self.options.cert])
+                cmd_line.extend(["--cert", self.options.cert])
 
         if get_flag(S2N_FIPS_MODE):
             cmd_line.append("--enter-fips-mode")
@@ -275,49 +288,50 @@ class S2N(Provider):
 
     def setup_server(self):
         # s2nd prints this message after it begins listening for connections
-        self.ready_to_test_marker = 'Listening on'
+        self.ready_to_test_marker = "Listening on"
 
         """
         Using the passed ProviderOptions, create a command line.
         """
         cmd_line = []
         if self.options.use_mainline_version is True:
-            cmd_line.append('s2nd_head')
+            cmd_line.append("s2nd_head")
         else:
-            cmd_line.append('s2nd')
-        cmd_line.extend(['-X', '--self-service-blinding', '--non-blocking'])
+            cmd_line.append("s2nd")
+        cmd_line.extend(["-X", "--self-service-blinding", "--non-blocking"])
 
         if self.options.key is not None:
-            cmd_line.extend(['--key', self.options.key])
+            cmd_line.extend(["--key", self.options.key])
         if self.options.cert is not None:
-            cmd_line.extend(['--cert', self.options.cert])
+            cmd_line.extend(["--cert", self.options.cert])
 
         if self.options.insecure is True:
-            cmd_line.append('--insecure')
+            cmd_line.append("--insecure")
         elif self.options.trust_store:
-            cmd_line.extend(['-t', self.options.trust_store])
+            cmd_line.extend(["-t", self.options.trust_store])
         elif self.options.cert:
-            cmd_line.extend(['-t', self.options.cert])
+            cmd_line.extend(["-t", self.options.cert])
 
         # If the test provided a cipher (security policy) that is compatible with
         # s2n, we'll use it. Otherwise, default to the appropriate `test_all` policy.
-        cipher_prefs = 'test_all_tls12'
+        cipher_prefs = "test_all_tls12"
         if self.options.protocol is Protocols.TLS13:
-            cipher_prefs = 'test_all'
+            cipher_prefs = "test_all"
         if self.options.cipher and self.options.cipher.s2n:
             cipher_prefs = self.options.cipher.name
 
-        cmd_line.extend(['-c', cipher_prefs])
+        cmd_line.extend(["-c", cipher_prefs])
 
         if self.options.use_client_auth is True:
-            cmd_line.append('-m')
+            cmd_line.append("-m")
 
         if self.options.use_session_ticket is False:
-            cmd_line.append('-T')
+            cmd_line.append("-T")
 
         if self.options.reconnects_before_exit is not None:
             cmd_line.append(
-                '--max-conns={}'.format(self.options.reconnects_before_exit))
+                "--max-conns={}".format(self.options.reconnects_before_exit)
+            )
 
         if get_flag(S2N_FIPS_MODE):
             cmd_line.append("--enter-fips-mode")
@@ -334,8 +348,6 @@ class S2N(Provider):
 
 
 class OpenSSL(Provider):
-    _version = get_flag(S2N_PROVIDER_VERSION)
-
     def __init__(self, options: ProviderOptions):
         Provider.__init__(self, options)
         # We print some OpenSSL logging that includes stderr
@@ -345,7 +357,7 @@ class OpenSSL(Provider):
 
     @classmethod
     def get_send_marker(cls):
-        return 'Verify return code'
+        return "Verify return code"
 
     def _join_ciphers(self, ciphers):
         """
@@ -357,7 +369,7 @@ class OpenSSL(Provider):
         for c in ciphers:
             cipher_list.append(c.name)
 
-        ciphers = ':'.join(cipher_list)
+        ciphers = ":".join(cipher_list)
 
         return ciphers
 
@@ -368,32 +380,38 @@ class OpenSSL(Provider):
         if type(cipher) is list:
             # In the case of a cipher list we need to be sure TLS13 specific ciphers aren't
             # mixed with ciphers from previous versions
-            is_tls13_or_above = (cipher[0].min_version >= Protocols.TLS13)
-            mismatch = [c for c in cipher if (
-                c.min_version >= Protocols.TLS13) != is_tls13_or_above]
+            is_tls13_or_above = cipher[0].min_version >= Protocols.TLS13
+            mismatch = [
+                c
+                for c in cipher
+                if (c.min_version >= Protocols.TLS13) != is_tls13_or_above
+            ]
 
             if len(mismatch) > 0:
-                raise Exception("Cannot combine ciphers for TLS1.3 or above with older ciphers: {}".format(
-                    [c.name for c in cipher]))
+                raise Exception(
+                    "Cannot combine ciphers for TLS1.3 or above with older ciphers: {}".format(
+                        [c.name for c in cipher]
+                    )
+                )
 
             ciphers.append(self._join_ciphers(cipher))
         else:
-            is_tls13_or_above = (cipher.min_version >= Protocols.TLS13)
+            is_tls13_or_above = cipher.min_version >= Protocols.TLS13
             ciphers.append(cipher.name)
 
         if is_tls13_or_above:
-            cmdline.append('-ciphersuites')
+            cmdline.append("-ciphersuites")
         else:
-            cmdline.append('-cipher')
+            cmdline.append("-cipher")
 
         return cmdline + ciphers
 
     @classmethod
     def get_version(cls):
-        return cls._version
+        return get_flag(S2N_PROVIDER_VERSION)
 
     @classmethod
-    def supports_protocol(cls, protocol, with_cert=None):
+    def supports_protocol(cls, protocol):
         if protocol is Protocols.SSLv3:
             return False
 
@@ -404,70 +422,74 @@ class OpenSSL(Provider):
         return True
 
     def _is_openssl_11(self) -> None:
-        result = subprocess.run(["openssl", "version"], shell=False, capture_output=True, text=True)
+        result = subprocess.run(
+            ["openssl", "version"], shell=False, capture_output=True, text=True
+        )
         version_str = result.stdout.split(" ")
         project = version_str[0]
         version = version_str[1]
         print(f"openssl version: {project} version: {version}")
-        if (project != "OpenSSL" or version[0:3] != "1.1"):
-            raise FileNotFoundError(f"Openssl version returned {version}, expected 1.1.x.")
+        if project != "OpenSSL" or version[0:3] != "1.1":
+            raise FileNotFoundError(
+                f"Openssl version returned {version}, expected 1.1.x."
+            )
 
     def setup_client(self):
-        cmd_line = ['openssl', 's_client']
+        cmd_line = ["openssl", "s_client"]
         cmd_line.extend(
-            ['-connect', '{}:{}'.format(self.options.host, self.options.port)])
+            ["-connect", "{}:{}".format(self.options.host, self.options.port)]
+        )
 
         # Additional debugging that will be captured incase of failure
         if self.options.verbose:
-            cmd_line.append('-debug')
+            cmd_line.append("-debug")
 
-        cmd_line.extend(['-tlsextdebug', '-state'])
+        cmd_line.extend(["-tlsextdebug", "-state"])
 
         if self.options.key is not None:
-            cmd_line.extend(['-key', self.options.key])
+            cmd_line.extend(["-key", self.options.key])
 
         # Unlike s2n, OpenSSL allows us to be much more specific about which TLS
         # protocol to use.
         if self.options.protocol == Protocols.TLS13:
-            cmd_line.append('-tls1_3')
+            cmd_line.append("-tls1_3")
         elif self.options.protocol == Protocols.TLS12:
-            cmd_line.append('-tls1_2')
+            cmd_line.append("-tls1_2")
         elif self.options.protocol == Protocols.TLS11:
-            cmd_line.append('-tls1_1')
+            cmd_line.append("-tls1_1")
         elif self.options.protocol == Protocols.TLS10:
-            cmd_line.append('-tls1')
+            cmd_line.append("-tls1")
         elif self.options.protocol == Protocols.SSLv3:
-            cmd_line.append('-ssl3')
+            cmd_line.append("-ssl3")
 
         if self.options.cipher is not None:
             cmd_line.extend(self._cipher_to_cmdline(self.options.cipher))
 
         if self.options.curve is not None:
-            cmd_line.extend(['-curves', str(self.options.curve)])
+            cmd_line.extend(["-curves", str(self.options.curve)])
 
         if self.options.use_client_auth:
             if self.options.key:
-                cmd_line.extend(['-key', self.options.key])
+                cmd_line.extend(["-key", self.options.key])
             if self.options.cert:
-                cmd_line.extend(['-cert', self.options.cert])
+                cmd_line.extend(["-cert", self.options.cert])
 
         if self.options.reconnect is True:
-            cmd_line.append('-reconnect')
+            cmd_line.append("-reconnect")
 
         if self.options.extra_flags is not None:
             cmd_line.extend(self.options.extra_flags)
 
         if self.options.server_name is not None:
-            cmd_line.extend(['-servername', self.options.server_name])
+            cmd_line.extend(["-servername", self.options.server_name])
             if self.options.verify_hostname is not None:
-                cmd_line.extend(['-verify_hostname', self.options.server_name])
+                cmd_line.extend(["-verify_hostname", self.options.server_name])
 
         if self.options.enable_client_ocsp:
             cmd_line.append("-status")
 
         if self.options.signature_algorithm is not None:
-            cmd_line.extend(
-                ["-sigalgs", self.options.signature_algorithm.name])
+            cmd_line.extend(["-sigalgs", self.options.signature_algorithm.name])
 
         if self.options.record_size is not None:
             cmd_line.extend(["-max_send_frag", str(self.options.record_size)])
@@ -479,60 +501,58 @@ class OpenSSL(Provider):
 
     def setup_server(self):
         # s_server prints this message before it is ready to send/receive data
-        self.ready_to_test_marker = 'ACCEPT'
+        self.ready_to_test_marker = "ACCEPT"
 
-        cmd_line = ['openssl', 's_server']
-        cmd_line.extend(['-accept', '{}'.format(self.options.port)])
+        cmd_line = ["openssl", "s_server"]
+        cmd_line.extend(["-accept", "{}".format(self.options.port)])
 
         if self.options.reconnects_before_exit is not None:
             # If the user request a specific reconnection count, set it here
-            cmd_line.extend(
-                ['-naccept', str(self.options.reconnects_before_exit)])
+            cmd_line.extend(["-naccept", str(self.options.reconnects_before_exit)])
         else:
             # Exit after the first connection by default
-            cmd_line.extend(['-naccept', '1'])
+            cmd_line.extend(["-naccept", "1"])
 
         # Additional debugging that will be captured incase of failure
         if self.options.verbose:
-            cmd_line.append('-debug')
+            cmd_line.append("-debug")
 
-        cmd_line.extend(['-tlsextdebug', '-state'])
+        cmd_line.extend(["-tlsextdebug", "-state"])
 
         if self.options.cert is not None:
-            cmd_line.extend(['-cert', self.options.cert])
+            cmd_line.extend(["-cert", self.options.cert])
         if self.options.key is not None:
-            cmd_line.extend(['-key', self.options.key])
+            cmd_line.extend(["-key", self.options.key])
 
         # Unlike s2n, OpenSSL allows us to be much more specific about which TLS
         # protocol to use.
         if self.options.protocol == Protocols.TLS13:
-            cmd_line.append('-tls1_3')
+            cmd_line.append("-tls1_3")
         elif self.options.protocol == Protocols.TLS12:
-            cmd_line.append('-tls1_2')
+            cmd_line.append("-tls1_2")
         elif self.options.protocol == Protocols.TLS11:
-            cmd_line.append('-tls1_1')
+            cmd_line.append("-tls1_1")
         elif self.options.protocol == Protocols.TLS10:
-            cmd_line.append('-tls1')
+            cmd_line.append("-tls1")
         elif self.options.protocol == Protocols.SSLv3:
-            cmd_line.append('-ssl3')
+            cmd_line.append("-ssl3")
 
         if self.options.cipher is not None:
             cmd_line.extend(self._cipher_to_cmdline(self.options.cipher))
             if self.options.cipher.parameters is not None:
-                cmd_line.extend(['-dhparam', self.options.cipher.parameters])
+                cmd_line.extend(["-dhparam", self.options.cipher.parameters])
 
         if self.options.curve is not None:
-            cmd_line.extend(['-curves', str(self.options.curve)])
+            cmd_line.extend(["-curves", str(self.options.curve)])
         if self.options.use_client_auth is True:
             # We use "Verify" instead of "verify" to require a client cert
-            cmd_line.extend(['-Verify', '1'])
+            cmd_line.extend(["-Verify", "1"])
 
         if self.options.ocsp_response is not None:
             cmd_line.extend(["-status_file", self.options.ocsp_response])
 
         if self.options.signature_algorithm is not None:
-            cmd_line.extend(
-                ["-sigalgs", self.options.signature_algorithm.name])
+            cmd_line.extend(["-sigalgs", self.options.signature_algorithm.name])
 
         if self.options.extra_flags is not None:
             cmd_line.extend(self.options.extra_flags)
@@ -554,7 +574,7 @@ class SSLv3Provider(OpenSSL):
         options.env_overrides = override_env_vars
 
     @classmethod
-    def supports_protocol(cls, protocol, with_cert=None):
+    def supports_protocol(cls, protocol):
         if protocol is Protocols.SSLv3:
             return True
         return False
@@ -574,9 +594,13 @@ class JavaSSL(Provider):
         return "Starting handshake"
 
     @classmethod
-    def supports_protocol(cls, protocol, with_cert=None):
+    def supports_protocol(cls, protocol):
         # https://aws.amazon.com/blogs/opensource/tls-1-0-1-1-changes-in-openjdk-and-amazon-corretto/
-        if protocol is Protocols.SSLv3 or protocol is Protocols.TLS10 or protocol is Protocols.TLS11:
+        if (
+            protocol is Protocols.SSLv3
+            or protocol is Protocols.TLS10
+            or protocol is Protocols.TLS11
+        ):
             return False
 
         return True
@@ -584,16 +608,16 @@ class JavaSSL(Provider):
     @classmethod
     def supports_cipher(cls, cipher, with_curve=None):
         # Java SSL does not support CHACHA20
-        if 'CHACHA20' in cipher.name:
+        if "CHACHA20" in cipher.name:
             return False
 
         return True
 
     def setup_server(self):
-        pytest.skip('JavaSSL does not support server mode at this time')
+        pytest.skip("JavaSSL does not support server mode at this time")
 
     def setup_client(self):
-        cmd_line = ['java', "-classpath", "bin", "SSLSocketClient"]
+        cmd_line = ["java", "-classpath", "bin", "SSLSocketClient"]
 
         if self.options.port is not None:
             cmd_line.extend([self.options.port])
@@ -602,12 +626,15 @@ class JavaSSL(Provider):
             cmd_line.extend([self.options.trust_store])
         elif self.options.cert:
             cmd_line.extend([self.options.cert])
+        if self.options.cipher.iana_standard_name is not None:
+            cmd_line.extend([self.options.cipher.iana_standard_name])
 
         if self.options.protocol is not None:
             cmd_line.extend([self.options.protocol.name])
-
-        if self.options.cipher.iana_standard_name is not None:
-            cmd_line.extend([self.options.cipher.iana_standard_name])
+        # SSLv2ClientHello is a "protocol" for Java TLS, so we append it next to
+        # the existing protocol.
+        if self.options.extra_flags is not None:
+            cmd_line.extend(self.options.extra_flags)
 
         # Clients are always ready to connect
         self.set_provider_ready()
@@ -627,29 +654,30 @@ class BoringSSL(Provider):
 
     @classmethod
     def get_send_marker(cls):
-        return 'Cert issuer:'
+        return "Cert issuer:"
 
     def setup_server(self):
-        cmd_line = ['bssl', 's_server']
-        cmd_line.extend(['-accept', self.options.port])
+        cmd_line = ["bssl", "s_server"]
+        cmd_line.extend(["-accept", self.options.port])
         if self.options.cert is not None:
-            cmd_line.extend(['-cert', self.options.cert])
+            cmd_line.extend(["-cert", self.options.cert])
         if self.options.key is not None:
-            cmd_line.extend(['-key', self.options.key])
+            cmd_line.extend(["-key", self.options.key])
         if self.options.curve is not None:
             if self.options.curve == Curves.P256:
-                cmd_line.extend(['-curves', 'P-256'])
+                cmd_line.extend(["-curves", "P-256"])
             elif self.options.curve == Curves.P384:
-                cmd_line.extend(['-curves', 'P-384'])
+                cmd_line.extend(["-curves", "P-384"])
             elif self.options.curve == Curves.P521:
-                cmd_line.extend(['-curves', 'P-521'])
+                cmd_line.extend(["-curves", "P-521"])
             elif self.options.curve == Curves.SecP256r1Kyber768Draft00:
-                cmd_line.extend(['-curves', 'SecP256r1Kyber768Draft00'])
+                cmd_line.extend(["-curves", "SecP256r1Kyber768Draft00"])
             elif self.options.curve == Curves.X25519Kyber768Draft00:
-                cmd_line.extend(['-curves', 'X25519Kyber768Draft00'])
+                cmd_line.extend(["-curves", "X25519Kyber768Draft00"])
             elif self.options.curve == Curves.X25519:
-                pytest.skip('BoringSSL does not support curve {}'.format(
-                    self.options.curve))
+                pytest.skip(
+                    "BoringSSL does not support curve {}".format(self.options.curve)
+                )
 
         if self.options.extra_flags is not None:
             cmd_line.extend(self.options.extra_flags)
@@ -657,37 +685,42 @@ class BoringSSL(Provider):
         return cmd_line
 
     def setup_client(self):
-        cmd_line = ['bssl', 's_client']
+        cmd_line = ["bssl", "s_client"]
         cmd_line.extend(
-            ['-connect', '{}:{}'.format(self.options.host, self.options.port)])
+            ["-connect", "{}:{}".format(self.options.host, self.options.port)]
+        )
         if self.options.cert is not None:
-            cmd_line.extend(['-cert', self.options.cert])
+            cmd_line.extend(["-cert", self.options.cert])
         if self.options.key is not None:
-            cmd_line.extend(['-key', self.options.key])
+            cmd_line.extend(["-key", self.options.key])
         if self.options.cipher is not None:
             if self.options.cipher == Ciphersuites.TLS_CHACHA20_POLY1305_SHA256:
                 cmd_line.extend(
-                    ['-cipher', 'TLS_ECDHE_ECDSA_WITH_CHACHA20_POLY1305_SHA256'])
+                    ["-cipher", "TLS_ECDHE_ECDSA_WITH_CHACHA20_POLY1305_SHA256"]
+                )
             elif self.options.cipher == Ciphersuites.TLS_AES_128_GCM_256:
-                pytest.skip('BoringSSL does not support Cipher {}'.format(
-                    self.options.cipher))
+                pytest.skip(
+                    "BoringSSL does not support Cipher {}".format(self.options.cipher)
+                )
             elif self.options.cipher == Ciphersuites.TLS_AES_256_GCM_384:
-                pytest.skip('BoringSSL does not support Cipher {}'.format(
-                    self.options.cipher))
+                pytest.skip(
+                    "BoringSSL does not support Cipher {}".format(self.options.cipher)
+                )
         if self.options.curve is not None:
             if self.options.curve == Curves.P256:
-                cmd_line.extend(['-curves', 'P-256'])
+                cmd_line.extend(["-curves", "P-256"])
             elif self.options.curve == Curves.P384:
-                cmd_line.extend(['-curves', 'P-384'])
+                cmd_line.extend(["-curves", "P-384"])
             elif self.options.curve == Curves.P521:
-                cmd_line.extend(['-curves', 'P-521'])
+                cmd_line.extend(["-curves", "P-521"])
             elif self.options.curve == Curves.SecP256r1Kyber768Draft00:
-                cmd_line.extend(['-curves', 'SecP256r1Kyber768Draft00'])
+                cmd_line.extend(["-curves", "SecP256r1Kyber768Draft00"])
             elif self.options.curve == Curves.X25519Kyber768Draft00:
-                cmd_line.extend(['-curves', 'X25519Kyber768Draft00'])
+                cmd_line.extend(["-curves", "X25519Kyber768Draft00"])
             elif self.options.curve == Curves.X25519:
-                pytest.skip('BoringSSL does not support curve {}'.format(
-                    self.options.curve))
+                pytest.skip(
+                    "BoringSSL does not support curve {}".format(self.options.curve)
+                )
 
         if self.options.extra_flags is not None:
             cmd_line.extend(self.options.extra_flags)
@@ -708,35 +741,32 @@ class GnuTLS(Provider):
     @staticmethod
     def cipher_to_priority_str(cipher):
         return {
-            Ciphers.DHE_RSA_AES128_SHA:         "DHE-RSA:+AES-128-CBC:+SHA1",
-            Ciphers.DHE_RSA_AES256_SHA:         "DHE-RSA:+AES-256-CBC:+SHA1",
-            Ciphers.DHE_RSA_AES128_SHA256:      "DHE-RSA:+AES-128-CBC:+SHA256",
-            Ciphers.DHE_RSA_AES256_SHA256:      "DHE-RSA:+AES-256-CBC:+SHA256",
-            Ciphers.DHE_RSA_AES128_GCM_SHA256:  "DHE-RSA:+AES-128-GCM:+AEAD",
-            Ciphers.DHE_RSA_AES256_GCM_SHA384:  "DHE-RSA:+AES-256-GCM:+AEAD",
-            Ciphers.DHE_RSA_CHACHA20_POLY1305:  "DHE-RSA:+CHACHA20-POLY1305:+AEAD",
-
-            Ciphers.AES128_SHA:         "RSA:+AES-128-CBC:+SHA1",
-            Ciphers.AES256_SHA:         "RSA:+AES-256-CBC:+SHA1",
-            Ciphers.AES128_SHA256:      "RSA:+AES-128-CBC:+SHA256",
-            Ciphers.AES256_SHA256:      "RSA:+AES-256-CBC:+SHA256",
-            Ciphers.AES128_GCM_SHA256:  "RSA:+AES-128-GCM:+AEAD",
-            Ciphers.AES256_GCM_SHA384:  "RSA:+AES-256-GCM:+AEAD",
-
-            Ciphers.ECDHE_ECDSA_AES128_SHA:         "ECDHE-ECDSA:+AES-128-CBC:+SHA1",
-            Ciphers.ECDHE_ECDSA_AES256_SHA:         "ECDHE-ECDSA:+AES-256-CBC:+SHA1",
-            Ciphers.ECDHE_ECDSA_AES128_SHA256:      "ECDHE-ECDSA:+AES-128-CBC:+SHA256",
-            Ciphers.ECDHE_ECDSA_AES256_SHA384:      "ECDHE-ECDSA:+AES-256-CBC:+SHA384",
-            Ciphers.ECDHE_ECDSA_AES128_GCM_SHA256:  "ECDHE-ECDSA:+AES-128-GCM:+AEAD",
-            Ciphers.ECDHE_ECDSA_AES256_GCM_SHA384:  "ECDHE-ECDSA:+AES-256-GCM:+AEAD",
-
-            Ciphers.ECDHE_RSA_AES128_SHA:           "ECDHE-RSA:+AES-128-CBC:+SHA1",
-            Ciphers.ECDHE_RSA_AES256_SHA:           "ECDHE-RSA:+AES-256-CBC:+SHA1",
-            Ciphers.ECDHE_RSA_AES128_SHA256:        "ECDHE-RSA:+AES-128-CBC:+SHA256",
-            Ciphers.ECDHE_RSA_AES256_SHA384:        "ECDHE-RSA:+AES-256-CBC:+SHA384",
-            Ciphers.ECDHE_RSA_AES128_GCM_SHA256:    "ECDHE-RSA:+AES-128-GCM:+AEAD",
-            Ciphers.ECDHE_RSA_AES256_GCM_SHA384:    "ECDHE-RSA:+AES-256-GCM:+AEAD",
-            Ciphers.ECDHE_RSA_CHACHA20_POLY1305:    "ECDHE-RSA:+CHACHA20-POLY1305:+AEAD"
+            Ciphers.DHE_RSA_AES128_SHA: "DHE-RSA:+AES-128-CBC:+SHA1",
+            Ciphers.DHE_RSA_AES256_SHA: "DHE-RSA:+AES-256-CBC:+SHA1",
+            Ciphers.DHE_RSA_AES128_SHA256: "DHE-RSA:+AES-128-CBC:+SHA256",
+            Ciphers.DHE_RSA_AES256_SHA256: "DHE-RSA:+AES-256-CBC:+SHA256",
+            Ciphers.DHE_RSA_AES128_GCM_SHA256: "DHE-RSA:+AES-128-GCM:+AEAD",
+            Ciphers.DHE_RSA_AES256_GCM_SHA384: "DHE-RSA:+AES-256-GCM:+AEAD",
+            Ciphers.DHE_RSA_CHACHA20_POLY1305: "DHE-RSA:+CHACHA20-POLY1305:+AEAD",
+            Ciphers.AES128_SHA: "RSA:+AES-128-CBC:+SHA1",
+            Ciphers.AES256_SHA: "RSA:+AES-256-CBC:+SHA1",
+            Ciphers.AES128_SHA256: "RSA:+AES-128-CBC:+SHA256",
+            Ciphers.AES256_SHA256: "RSA:+AES-256-CBC:+SHA256",
+            Ciphers.AES128_GCM_SHA256: "RSA:+AES-128-GCM:+AEAD",
+            Ciphers.AES256_GCM_SHA384: "RSA:+AES-256-GCM:+AEAD",
+            Ciphers.ECDHE_ECDSA_AES128_SHA: "ECDHE-ECDSA:+AES-128-CBC:+SHA1",
+            Ciphers.ECDHE_ECDSA_AES256_SHA: "ECDHE-ECDSA:+AES-256-CBC:+SHA1",
+            Ciphers.ECDHE_ECDSA_AES128_SHA256: "ECDHE-ECDSA:+AES-128-CBC:+SHA256",
+            Ciphers.ECDHE_ECDSA_AES256_SHA384: "ECDHE-ECDSA:+AES-256-CBC:+SHA384",
+            Ciphers.ECDHE_ECDSA_AES128_GCM_SHA256: "ECDHE-ECDSA:+AES-128-GCM:+AEAD",
+            Ciphers.ECDHE_ECDSA_AES256_GCM_SHA384: "ECDHE-ECDSA:+AES-256-GCM:+AEAD",
+            Ciphers.ECDHE_RSA_AES128_SHA: "ECDHE-RSA:+AES-128-CBC:+SHA1",
+            Ciphers.ECDHE_RSA_AES256_SHA: "ECDHE-RSA:+AES-256-CBC:+SHA1",
+            Ciphers.ECDHE_RSA_AES128_SHA256: "ECDHE-RSA:+AES-128-CBC:+SHA256",
+            Ciphers.ECDHE_RSA_AES256_SHA384: "ECDHE-RSA:+AES-256-CBC:+SHA384",
+            Ciphers.ECDHE_RSA_AES128_GCM_SHA256: "ECDHE-RSA:+AES-128-GCM:+AEAD",
+            Ciphers.ECDHE_RSA_AES256_GCM_SHA384: "ECDHE-RSA:+AES-256-GCM:+AEAD",
+            Ciphers.ECDHE_RSA_CHACHA20_POLY1305: "ECDHE-RSA:+CHACHA20-POLY1305:+AEAD",
         }.get(cipher)
 
     @staticmethod
@@ -747,25 +777,25 @@ class GnuTLS(Provider):
             Protocols.TLS10.value: "VERS-TLS1.0",
             Protocols.TLS11.value: "VERS-TLS1.1",
             Protocols.TLS12.value: "VERS-TLS1.2",
-            Protocols.TLS13.value: "VERS-TLS1.3"
+            Protocols.TLS13.value: "VERS-TLS1.3",
         }.get(protocol.value)
 
     @staticmethod
     def curve_to_priority_str(curve):
         return {
-            Curves.P256:    "CURVE-SECP256R1",
-            Curves.P384:    "CURVE-SECP384R1",
-            Curves.P521:    "CURVE-SECP521R1",
-            Curves.X25519:  "CURVE-X25519"
+            Curves.P256: "CURVE-SECP256R1",
+            Curves.P384: "CURVE-SECP384R1",
+            Curves.P521: "CURVE-SECP521R1",
+            Curves.X25519: "CURVE-X25519",
         }.get(curve)
 
     @staticmethod
     def sigalg_to_priority_str(sigalg):
         return {
-            Signatures.RSA_SHA1:    "SIGN-RSA-SHA1",
-            Signatures.RSA_SHA256:  "SIGN-RSA-SHA256",
-            Signatures.RSA_SHA384:  "SIGN-RSA-SHA384",
-            Signatures.RSA_SHA512:  "SIGN-RSA-SHA512",
+            Signatures.RSA_SHA1: "SIGN-RSA-SHA1",
+            Signatures.RSA_SHA256: "SIGN-RSA-SHA256",
+            Signatures.RSA_SHA384: "SIGN-RSA-SHA384",
+            Signatures.RSA_SHA512: "SIGN-RSA-SHA512",
         }.get(sigalg)
 
     @classmethod
@@ -793,7 +823,9 @@ class GnuTLS(Provider):
         else:
             priority_str += ":+GROUP-ALL"
 
-        sigalg_to_priority_str = self.sigalg_to_priority_str(self.options.signature_algorithm)
+        sigalg_to_priority_str = self.sigalg_to_priority_str(
+            self.options.signature_algorithm
+        )
         if sigalg_to_priority_str:
             priority_str += ":+" + sigalg_to_priority_str
         else:
@@ -815,9 +847,11 @@ class GnuTLS(Provider):
 
         cmd_line = [
             "gnutls-cli",
-            "--port", str(self.options.port),
+            "--port",
+            str(self.options.port),
             self.options.host,
-            "--debug", "9999"
+            "--debug",
+            "9999",
         ]
 
         if self.options.verbose:
@@ -851,7 +885,7 @@ class GnuTLS(Provider):
             "gnutls-serv",
             f"--port={self.options.port}",
             "--echo",
-            "--debug=9999"
+            "--debug=9999",
         ]
 
         if self.options.cert is not None:
@@ -878,7 +912,7 @@ class GnuTLS(Provider):
         return cmd_line
 
     @classmethod
-    def supports_protocol(cls, protocol, with_cert=None):
+    def supports_protocol(cls, protocol):
         return GnuTLS.protocol_to_priority_str(protocol) is not None
 
     @classmethod
