@@ -1,8 +1,15 @@
+# Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# SPDX-License-Identifier: Apache-2.0
 import copy
 import os
 import pytest
 
-from configuration import available_ports, ALL_TEST_CURVES, ALL_TEST_CERTS, TLS13_CIPHERS
+from configuration import (
+    available_ports,
+    ALL_TEST_CURVES,
+    ALL_TEST_CERTS,
+    TLS13_CIPHERS,
+)
 from common import ProviderOptions, Protocols, Curves, data_bytes
 from fixtures import managed_process  # lgtm [py/unused-import]
 from providers import Provider, S2N as S2NBase, OpenSSL as OpenSSLBase
@@ -10,8 +17,8 @@ from utils import invalid_test_parameters, get_parameter_name, to_bytes
 
 from test_hello_retry_requests import S2N_HRR_MARKER
 
-TICKET_FILE = 'ticket'
-EARLY_DATA_FILE = 'early_data'
+TICKET_FILE = "ticket"
+EARLY_DATA_FILE = "early_data"
 
 MAX_EARLY_DATA = 500  # Arbitrary largish number
 DATA_TO_SEND = data_bytes(500)  # Arbitrary large number
@@ -21,19 +28,17 @@ NUM_CONNECTIONS = NUM_RESUMES + 1  # resumes + initial
 
 S2N_DEFAULT_CURVE = Curves.X25519
 # We have no plans to support this curve any time soon
-S2N_UNSUPPORTED_CURVE = 'X448'
-S2N_HRR_CURVES = list(
-    curve for curve in ALL_TEST_CURVES if curve != S2N_DEFAULT_CURVE)
+S2N_UNSUPPORTED_CURVE = "X448"
+S2N_HRR_CURVES = list(curve for curve in ALL_TEST_CURVES if curve != S2N_DEFAULT_CURVE)
 
 S2N_EARLY_DATA_MARKER = to_bytes("WITH_EARLY_DATA")
 S2N_EARLY_DATA_RECV_MARKER = "Early Data received: "
 S2N_EARLY_DATA_STATUS_MARKER = "Early Data status: {status}"
-S2N_EARLY_DATA_ACCEPTED_MARKER = S2N_EARLY_DATA_STATUS_MARKER.format(
-    status="ACCEPTED")
-S2N_EARLY_DATA_REJECTED_MARKER = S2N_EARLY_DATA_STATUS_MARKER.format(
-    status="REJECTED")
+S2N_EARLY_DATA_ACCEPTED_MARKER = S2N_EARLY_DATA_STATUS_MARKER.format(status="ACCEPTED")
+S2N_EARLY_DATA_REJECTED_MARKER = S2N_EARLY_DATA_STATUS_MARKER.format(status="REJECTED")
 S2N_EARLY_DATA_NOT_REQUESTED_MARKER = S2N_EARLY_DATA_STATUS_MARKER.format(
-    status="NOT REQUESTED")
+    status="NOT REQUESTED"
+)
 
 
 class S2N(S2NBase):
@@ -44,12 +49,12 @@ class S2N(S2NBase):
         cmd_line = S2NBase.setup_client(self)
         early_data_file = self.options.early_data_file
         if early_data_file and os.path.exists(early_data_file):
-            cmd_line.extend(['--early-data', early_data_file])
+            cmd_line.extend(["--early-data", early_data_file])
         return cmd_line
 
     def setup_server(self):
         cmd_line = S2NBase.setup_server(self)
-        cmd_line.extend(['--max-early-data', self.options.max_early_data])
+        cmd_line.extend(["--max-early-data", self.options.max_early_data])
         return cmd_line
 
 
@@ -61,19 +66,19 @@ class OpenSSL(OpenSSLBase):
         cmd_line = OpenSSLBase.setup_client(self)
         early_data_file = self.options.early_data_file
         if early_data_file and os.path.exists(early_data_file):
-            cmd_line.extend(['-early_data', early_data_file])
+            cmd_line.extend(["-early_data", early_data_file])
         ticket_file = self.options.ticket_file
         if ticket_file:
             if os.path.exists(ticket_file):
-                cmd_line.extend(['-sess_in', ticket_file])
+                cmd_line.extend(["-sess_in", ticket_file])
             else:
-                cmd_line.extend(['-sess_out', self.options.ticket_file])
+                cmd_line.extend(["-sess_out", self.options.ticket_file])
         return cmd_line
 
     def setup_server(self):
         cmd_line = OpenSSLBase.setup_server(self)
         if self.options.max_early_data > 0:
-            cmd_line.extend(['-early_data'])
+            cmd_line.extend(["-early_data"])
         return cmd_line
 
 
@@ -87,7 +92,7 @@ SERVER_PROVIDERS = [OpenSSL, S2N]
 
 def get_early_data_bytes(file_path, early_data_size):
     early_data = data_bytes(early_data_size)
-    with open(file_path, 'wb') as fout:
+    with open(file_path, "wb") as fout:
         fout.write(early_data)
     return early_data
 
@@ -116,16 +121,10 @@ def get_ticket_from_s2n_server(options, managed_process, provider, certificate):
     assert not os.path.exists(options.ticket_file)
 
     s2n_server = managed_process(
-        S2N,
-        server_options,
-        send_marker=S2N.get_send_marker(),
-        timeout=10
+        S2N, server_options, send_marker=S2N.get_send_marker(), timeout=10
     )
     client = managed_process(
-        provider,
-        client_options,
-        close_marker=str(close_marker_bytes),
-        timeout=10
+        provider, client_options, close_marker=str(close_marker_bytes), timeout=10
     )
 
     for results in s2n_server.get_results():
@@ -161,9 +160,21 @@ then another resumption connection with early data.
 @pytest.mark.parametrize("protocol", [Protocols.TLS13], ids=get_parameter_name)
 @pytest.mark.parametrize("provider", CLIENT_PROVIDERS, ids=get_parameter_name)
 @pytest.mark.parametrize("other_provider", [S2N], ids=get_parameter_name)
-@pytest.mark.parametrize("early_data_size", [int(MAX_EARLY_DATA/2), int(MAX_EARLY_DATA-1), MAX_EARLY_DATA, 1])
-def test_s2n_server_with_early_data(managed_process, tmp_path, cipher, curve, certificate, protocol, provider,
-                                    other_provider, early_data_size):
+@pytest.mark.parametrize(
+    "early_data_size",
+    [int(MAX_EARLY_DATA / 2), int(MAX_EARLY_DATA - 1), MAX_EARLY_DATA, 1],
+)
+def test_s2n_server_with_early_data(
+    managed_process,
+    tmp_path,
+    cipher,
+    curve,
+    certificate,
+    protocol,
+    provider,
+    other_provider,
+    early_data_size,
+):
     ticket_file = str(tmp_path / TICKET_FILE)
     early_data_file = str(tmp_path / EARLY_DATA_FILE)
     early_data = get_early_data_bytes(early_data_file, early_data_size)
@@ -198,8 +209,7 @@ def test_s2n_server_with_early_data(managed_process, tmp_path, cipher, curve, ce
     for results in s2n_server.get_results():
         results.assert_success()
         assert S2N_EARLY_DATA_MARKER in results.stdout
-        assert (to_bytes(S2N_EARLY_DATA_RECV_MARKER) +
-                early_data) in results.stdout
+        assert (to_bytes(S2N_EARLY_DATA_RECV_MARKER) + early_data) in results.stdout
         assert to_bytes(S2N_EARLY_DATA_ACCEPTED_MARKER) in results.stdout
         assert DATA_TO_SEND in results.stdout
 
@@ -218,9 +228,20 @@ That means we don't need to manually perform the initial full connection, and th
 @pytest.mark.parametrize("protocol", [Protocols.TLS13], ids=get_parameter_name)
 @pytest.mark.parametrize("provider", SERVER_PROVIDERS, ids=get_parameter_name)
 @pytest.mark.parametrize("other_provider", [S2N], ids=get_parameter_name)
-@pytest.mark.parametrize("early_data_size", [int(MAX_EARLY_DATA/2), int(MAX_EARLY_DATA-1), MAX_EARLY_DATA, 1])
-def test_s2n_client_with_early_data(managed_process, tmp_path, cipher, certificate, protocol, provider, other_provider,
-                                    early_data_size):
+@pytest.mark.parametrize(
+    "early_data_size",
+    [int(MAX_EARLY_DATA / 2), int(MAX_EARLY_DATA - 1), MAX_EARLY_DATA, 1],
+)
+def test_s2n_client_with_early_data(
+    managed_process,
+    tmp_path,
+    cipher,
+    certificate,
+    protocol,
+    provider,
+    other_provider,
+    early_data_size,
+):
     early_data_file = str(tmp_path / EARLY_DATA_FILE)
     early_data = get_early_data_bytes(early_data_file, early_data_size)
 
@@ -251,8 +272,10 @@ def test_s2n_client_with_early_data(managed_process, tmp_path, cipher, certifica
     for results in s2n_client.get_results():
         results.assert_success()
         assert S2N_EARLY_DATA_MARKER in results.stdout
-        assert results.stdout.count(
-            to_bytes(S2N_EARLY_DATA_ACCEPTED_MARKER)) == NUM_RESUMES
+        assert (
+            results.stdout.count(to_bytes(S2N_EARLY_DATA_ACCEPTED_MARKER))
+            == NUM_RESUMES
+        )
 
     for results in server.get_results():
         results.assert_success()
@@ -273,8 +296,9 @@ test_session_resumption but with validation that no early data is sent.
 @pytest.mark.parametrize("protocol", [Protocols.TLS13], ids=get_parameter_name)
 @pytest.mark.parametrize("provider", SERVER_PROVIDERS, ids=get_parameter_name)
 @pytest.mark.parametrize("other_provider", [S2N], ids=get_parameter_name)
-def test_s2n_client_without_early_data(managed_process, tmp_path, cipher, certificate, protocol, provider,
-                                       other_provider):
+def test_s2n_client_without_early_data(
+    managed_process, tmp_path, cipher, certificate, protocol, provider, other_provider
+):
     early_data_file = str(tmp_path / EARLY_DATA_FILE)
     early_data = get_early_data_bytes(early_data_file, MAX_EARLY_DATA)
 
@@ -309,8 +333,10 @@ def test_s2n_client_without_early_data(managed_process, tmp_path, cipher, certif
     for results in s2n_client.get_results():
         results.assert_success()
         assert S2N_EARLY_DATA_MARKER not in results.stdout
-        assert results.stdout.count(
-            to_bytes(S2N_EARLY_DATA_NOT_REQUESTED_MARKER)) == NUM_CONNECTIONS
+        assert (
+            results.stdout.count(to_bytes(S2N_EARLY_DATA_NOT_REQUESTED_MARKER))
+            == NUM_CONNECTIONS
+        )
 
 
 """
@@ -332,9 +358,21 @@ reconnects automatically, without any mechanism to modify the connection in betw
 @pytest.mark.parametrize("protocol", [Protocols.TLS13], ids=get_parameter_name)
 @pytest.mark.parametrize("provider", CLIENT_PROVIDERS, ids=get_parameter_name)
 @pytest.mark.parametrize("other_provider", [S2N], ids=get_parameter_name)
-@pytest.mark.parametrize("early_data_size", [int(MAX_EARLY_DATA/2), int(MAX_EARLY_DATA-1), MAX_EARLY_DATA, 1])
-def test_s2n_server_with_early_data_rejected(managed_process, tmp_path, cipher, curve, certificate, protocol, provider,
-                                             other_provider, early_data_size):
+@pytest.mark.parametrize(
+    "early_data_size",
+    [int(MAX_EARLY_DATA / 2), int(MAX_EARLY_DATA - 1), MAX_EARLY_DATA, 1],
+)
+def test_s2n_server_with_early_data_rejected(
+    managed_process,
+    tmp_path,
+    cipher,
+    curve,
+    certificate,
+    protocol,
+    provider,
+    other_provider,
+    early_data_size,
+):
     ticket_file = str(tmp_path / TICKET_FILE)
     early_data_file = str(tmp_path / EARLY_DATA_FILE)
     get_early_data_bytes(early_data_file, early_data_size)
@@ -391,12 +429,25 @@ does not send key shares for.
 @pytest.mark.parametrize("protocol", [Protocols.TLS13], ids=get_parameter_name)
 @pytest.mark.parametrize("provider", SERVER_PROVIDERS, ids=get_parameter_name)
 @pytest.mark.parametrize("other_provider", [S2N], ids=get_parameter_name)
-@pytest.mark.parametrize("early_data_size", [int(MAX_EARLY_DATA/2), int(MAX_EARLY_DATA-1), MAX_EARLY_DATA, 1])
-def test_s2n_client_with_early_data_rejected_via_hrr(managed_process, tmp_path, cipher, curve, certificate, protocol,
-                                                     provider, other_provider, early_data_size):
+@pytest.mark.parametrize(
+    "early_data_size",
+    [int(MAX_EARLY_DATA / 2), int(MAX_EARLY_DATA - 1), MAX_EARLY_DATA, 1],
+)
+def test_s2n_client_with_early_data_rejected_via_hrr(
+    managed_process,
+    tmp_path,
+    cipher,
+    curve,
+    certificate,
+    protocol,
+    provider,
+    other_provider,
+    early_data_size,
+):
     if provider == S2N:
         pytest.skip(
-            "S2N does not respect ProviderOptions.curve, so does not trigger a retry")
+            "S2N does not respect ProviderOptions.curve, so does not trigger a retry"
+        )
 
     early_data_file = str(tmp_path / EARLY_DATA_FILE)
     early_data = get_early_data_bytes(early_data_file, early_data_size)
@@ -430,8 +481,10 @@ def test_s2n_client_with_early_data_rejected_via_hrr(managed_process, tmp_path,
         results.assert_success()
         assert S2N_EARLY_DATA_MARKER not in results.stdout
         assert S2N_HRR_MARKER in results.stdout
-        assert results.stdout.count(
-            to_bytes(S2N_EARLY_DATA_REJECTED_MARKER)) == NUM_RESUMES
+        assert (
+            results.stdout.count(to_bytes(S2N_EARLY_DATA_REJECTED_MARKER))
+            == NUM_RESUMES
+        )
 
     for results in server.get_results():
         results.assert_success()
@@ -453,9 +506,21 @@ S2N doesn't support while still supporting at least one curve S2N does support.
 @pytest.mark.parametrize("protocol", [Protocols.TLS13], ids=get_parameter_name)
 @pytest.mark.parametrize("provider", CLIENT_PROVIDERS, ids=get_parameter_name)
 @pytest.mark.parametrize("other_provider", [S2N], ids=get_parameter_name)
-@pytest.mark.parametrize("early_data_size", [int(MAX_EARLY_DATA/2), int(MAX_EARLY_DATA-1), MAX_EARLY_DATA, 1])
-def test_s2n_server_with_early_data_rejected_via_hrr(managed_process, tmp_path, cipher, curve, certificate, protocol,
-                                                     provider, other_provider, early_data_size):
+@pytest.mark.parametrize(
+    "early_data_size",
+    [int(MAX_EARLY_DATA / 2), int(MAX_EARLY_DATA - 1), MAX_EARLY_DATA, 1],
+)
+def test_s2n_server_with_early_data_rejected_via_hrr(
+    managed_process,
+    tmp_path,
+    cipher,
+    curve,
+    certificate,
+    protocol,
+    provider,
+    other_provider,
+    early_data_size,
+):
     ticket_file = str(tmp_path / TICKET_FILE)
     early_data_file = str(tmp_path / EARLY_DATA_FILE)
     early_data = get_early_data_bytes(early_data_file, early_data_size)
@@ -510,12 +575,22 @@ Test the S2N server fails if it receives too much early data.
 @pytest.mark.parametrize("provider", CLIENT_PROVIDERS, ids=get_parameter_name)
 @pytest.mark.parametrize("other_provider", [S2N], ids=get_parameter_name)
 @pytest.mark.parametrize("excess_early_data", [1, 10, MAX_EARLY_DATA])
-def test_s2n_server_with_early_data_max_exceeded(managed_process, tmp_path, cipher, curve, certificate, protocol,
-                                                 provider, other_provider, excess_early_data):
+def test_s2n_server_with_early_data_max_exceeded(
+    managed_process,
+    tmp_path,
+    cipher,
+    curve,
+    certificate,
+    protocol,
+    provider,
+    other_provider,
+    excess_early_data,
+):
     ticket_file = str(tmp_path / TICKET_FILE)
     early_data_file = str(tmp_path / EARLY_DATA_FILE)
     early_data = get_early_data_bytes(
-        early_data_file, MAX_EARLY_DATA + excess_early_data)
+        early_data_file, MAX_EARLY_DATA + excess_early_data
+    )
 
     options = ProviderOptions(
         port=next(available_ports),
@@ -558,6 +633,7 @@ def test_s2n_server_with_early_data_max_exceeded(managed_process, tmp_path, ciph
         # Full early data should not be reported
         assert early_data not in results.stdout
         # Partial early data should be reported
-        assert (to_bytes(S2N_EARLY_DATA_RECV_MARKER) +
-                early_data[:MAX_EARLY_DATA]) in results.stdout
+        assert (
+            to_bytes(S2N_EARLY_DATA_RECV_MARKER) + early_data[:MAX_EARLY_DATA]
+        ) in results.stdout
         assert to_bytes("Bad message encountered") in results.stderr
