@@ -4,10 +4,15 @@ import copy
 import pytest
 
 from configuration import available_ports, ALL_TEST_CIPHERS, ALL_TEST_CERTS
-from common import ProviderOptions, Protocols, Certificates, Signatures, data_bytes, Ciphers
+from common import ProviderOptions, Protocols, Signatures, data_bytes
 from fixtures import managed_process  # lgtm [py/unused-import]
 from providers import Provider, S2N, OpenSSL, GnuTLS
-from utils import invalid_test_parameters, get_parameter_name, get_expected_s2n_version, to_bytes
+from utils import (
+    invalid_test_parameters,
+    get_parameter_name,
+    get_expected_s2n_version,
+    to_bytes,
+)
 
 all_sigs = [
     Signatures.RSA_SHA1,
@@ -33,7 +38,7 @@ def expected_signature(protocol, signature):
         # ECDSA by default hashes with SHA-1.
         #
         # This is inferred from extended version of TLS1.1 rfc- https://www.rfc-editor.org/rfc/rfc4492#section-5.10
-        if signature.sig_type == 'ECDSA':
+        if signature.sig_type == "ECDSA":
             signature = Signatures.ECDSA_SHA1
         else:
             signature = Signatures.RSA_MD5_SHA1
@@ -41,16 +46,19 @@ def expected_signature(protocol, signature):
 
 
 def signature_marker(mode, signature):
-    return to_bytes("{mode} signature negotiated: {type}+{digest}"
-                    .format(mode=mode.title(), type=signature.sig_type, digest=signature.sig_digest))
+    return to_bytes(
+        "{mode} signature negotiated: {type}+{digest}".format(
+            mode=mode.title(), type=signature.sig_type, digest=signature.sig_digest
+        )
+    )
 
 
 def skip_ciphers(*args, **kwargs):
-    provider = kwargs.get('provider')
-    cert = kwargs.get('certificate')
-    cipher = kwargs.get('cipher')
-    protocol = kwargs.get('protocol')
-    sigalg = kwargs.get('signature')
+    provider = kwargs.get("provider")
+    cert = kwargs.get("certificate")
+    cipher = kwargs.get("cipher")
+    protocol = kwargs.get("protocol")
+    sigalg = kwargs.get("signature")
 
     if not provider.supports_signature(sigalg):
         return True
@@ -74,12 +82,28 @@ def skip_ciphers(*args, **kwargs):
 @pytest.mark.parametrize("cipher", ALL_TEST_CIPHERS, ids=get_parameter_name)
 @pytest.mark.parametrize("provider", [OpenSSL, GnuTLS])
 @pytest.mark.parametrize("other_provider", [S2N])
-@pytest.mark.parametrize("protocol", [Protocols.TLS13, Protocols.TLS12, Protocols.TLS11], ids=get_parameter_name)
+@pytest.mark.parametrize(
+    "protocol",
+    [Protocols.TLS13, Protocols.TLS12, Protocols.TLS11],
+    ids=get_parameter_name,
+)
 @pytest.mark.parametrize("certificate", ALL_TEST_CERTS, ids=get_parameter_name)
 @pytest.mark.parametrize("signature", all_sigs, ids=get_parameter_name)
-@pytest.mark.parametrize("client_auth", [True, False], ids=lambda val: "client-auth" if val else "no-client-auth")
-def test_s2n_server_signature_algorithms(managed_process, cipher, provider, other_provider, protocol, certificate,
-                                         signature, client_auth):
+@pytest.mark.parametrize(
+    "client_auth",
+    [True, False],
+    ids=lambda val: "client-auth" if val else "no-client-auth",
+)
+def test_s2n_server_signature_algorithms(
+    managed_process,
+    cipher,
+    provider,
+    other_provider,
+    protocol,
+    certificate,
+    signature,
+    client_auth,
+):
     port = next(available_ports)
 
     random_bytes = data_bytes(64)
@@ -93,7 +117,7 @@ def test_s2n_server_signature_algorithms(managed_process, cipher, provider, othe
         key=certificate.key,
         cert=certificate.cert,
         signature_algorithm=signature,
-        protocol=protocol
+        protocol=protocol,
     )
 
     if provider == GnuTLS:
@@ -117,12 +141,22 @@ def test_s2n_server_signature_algorithms(managed_process, cipher, provider, othe
 
     for results in server.get_results():
         results.assert_success()
-        assert to_bytes("Actual protocol version: {}".format(
-            expected_version)) in results.stdout
-        assert signature_marker(Provider.ServerMode,
-                                expected_signature(protocol, signature)) in results.stdout
-        assert (signature_marker(Provider.ClientMode,
-                                 expected_signature(protocol, signature)) in results.stdout) == client_auth
+        assert (
+            to_bytes("Actual protocol version: {}".format(expected_version))
+            in results.stdout
+        )
+        assert (
+            signature_marker(
+                Provider.ServerMode, expected_signature(protocol, signature)
+            )
+            in results.stdout
+        )
+        assert (
+            signature_marker(
+                Provider.ClientMode, expected_signature(protocol, signature)
+            )
+            in results.stdout
+        ) == client_auth
         assert random_bytes in results.stdout
 
 
@@ -130,12 +164,28 @@ def test_s2n_server_signature_algorithms(managed_process, cipher, provider, othe
 @pytest.mark.parametrize("cipher", ALL_TEST_CIPHERS, ids=get_parameter_name)
 @pytest.mark.parametrize("provider", [OpenSSL, GnuTLS])
 @pytest.mark.parametrize("other_provider", [S2N])
-@pytest.mark.parametrize("protocol", [Protocols.TLS13, Protocols.TLS12, Protocols.TLS11], ids=get_parameter_name)
+@pytest.mark.parametrize(
+    "protocol",
+    [Protocols.TLS13, Protocols.TLS12, Protocols.TLS11],
+    ids=get_parameter_name,
+)
 @pytest.mark.parametrize("certificate", ALL_TEST_CERTS, ids=get_parameter_name)
 @pytest.mark.parametrize("signature", all_sigs, ids=get_parameter_name)
-@pytest.mark.parametrize("client_auth", [True, False], ids=lambda val: "client-auth" if val else "no-client-auth")
-def test_s2n_client_signature_algorithms(managed_process, cipher, provider, other_provider, protocol, certificate,
-                                         signature, client_auth):
+@pytest.mark.parametrize(
+    "client_auth",
+    [True, False],
+    ids=lambda val: "client-auth" if val else "no-client-auth",
+)
+def test_s2n_client_signature_algorithms(
+    managed_process,
+    cipher,
+    provider,
+    other_provider,
+    protocol,
+    certificate,
+    signature,
+    client_auth,
+):
     port = next(available_ports)
 
     random_bytes = data_bytes(64)
@@ -148,7 +198,8 @@ def test_s2n_client_signature_algorithms(managed_process, cipher, provider, othe
         use_client_auth=client_auth,
         key=certificate.key,
         cert=certificate.cert,
-        protocol=protocol)
+        protocol=protocol,
+    )
 
     server_options = copy.copy(client_options)
     server_options.data_to_send = None
@@ -162,14 +213,14 @@ def test_s2n_client_signature_algorithms(managed_process, cipher, provider, othe
     if provider == GnuTLS:
         kill_marker = random_bytes
 
-    server = managed_process(provider, server_options,
-                             timeout=5, kill_marker=kill_marker)
+    server = managed_process(
+        provider, server_options, timeout=5, kill_marker=kill_marker
+    )
     client = managed_process(S2N, client_options, timeout=5)
 
     for results in server.get_results():
         results.assert_success()
-        assert any(
-            [random_bytes in stream for stream in results.output_streams()])
+        assert any([random_bytes in stream for stream in results.output_streams()])
 
     expected_version = get_expected_s2n_version(protocol, provider)
 
@@ -181,14 +232,24 @@ def test_s2n_client_signature_algorithms(managed_process, cipher, provider, othe
     #
     # This mostly has to be inferred from the RFCs, but this blog post is a pretty good summary
     # of the situation: https://timtaubert.de/blog/2016/07/the-evolution-of-signatures-in-tls/
-    server_sigalg_used = not cipher.iana_standard_name.startswith(
-        "TLS_RSA_WITH_")
+    server_sigalg_used = not cipher.iana_standard_name.startswith("TLS_RSA_WITH_")
 
     for results in client.get_results():
         results.assert_success()
-        assert to_bytes("Actual protocol version: {}".format(
-            expected_version)) in results.stdout
-        assert signature_marker(
-            Provider.ServerMode, expected_signature(protocol, signature)) in results.stdout or not server_sigalg_used
-        assert (signature_marker(Provider.ClientMode, expected_signature(protocol, signature))
-                in results.stdout) == client_auth
+        assert (
+            to_bytes("Actual protocol version: {}".format(expected_version))
+            in results.stdout
+        )
+        assert (
+            signature_marker(
+                Provider.ServerMode, expected_signature(protocol, signature)
+            )
+            in results.stdout
+            or not server_sigalg_used
+        )
+        assert (
+            signature_marker(
+                Provider.ClientMode, expected_signature(protocol, signature)
+            )
+            in results.stdout
+        ) == client_auth
